@@ -1,5 +1,5 @@
 package CPAN::Testers::Schema::Result::TestReport;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 # ABSTRACT: Raw reports as JSON documents
 
 #pod =head1 SYNOPSIS
@@ -22,8 +22,12 @@ our $VERSION = '0.006';
 #pod =cut
 
 use CPAN::Testers::Schema::Base 'Result';
+use Data::UUID;
+use DateTime;
 table 'test_report';
 
+__PACKAGE__->load_components('InflateColumn::Serializer', 'Core');
+
 #pod =attr id
 #pod
 #pod The UUID of this report stored in standard hex string representation.
@@ -36,6 +40,18 @@ primary_column 'id', {
     is_nullable => 0,
 };
 
+#pod =attr created
+#pod
+#pod The ISO8601 date/time of when the report was inserted into the database.
+#pod Will default to the current time.
+#pod
+#pod =cut
+
+column created => {
+    data_type => 'datetime',
+    is_nullable => 0,
+};
+
 #pod =attr report
 #pod
 #pod The full JSON report.
@@ -46,7 +62,26 @@ primary_column 'id', {
 #pod =cut
 
 column 'report', {
-    data_type => 'JSON',
+    data_type            => 'JSON',
+    is_nullable          => 0,
+    'serializer_class'   => 'JSON',
+    'serializer_options' => { allow_blessed => 1, convert_blessed => 1 }
+};
+
+#pod =method new
+#pod
+#pod Create a new object. This is called automatically by the ResultSet
+#pod object and should not be called directly.
+#pod
+#pod This is overridden to provide sane defaults for the C<id> and C<created>
+#pod fields.
+#pod
+#pod =cut
+
+sub new( $class, $attrs ) {
+    $attrs->{report}{id} = $attrs->{id} ||= Data::UUID->new->create_str;
+    $attrs->{report}{created} = $attrs->{created} ||= DateTime->now( time_zone => 'UTC' )->datetime . 'Z';
+    return $class->next::method( $attrs );
 };
 
 1;
@@ -61,7 +96,7 @@ CPAN::Testers::Schema::Result::TestReport - Raw reports as JSON documents
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -82,6 +117,11 @@ by L<CPAN::Testers::Backend::ProcessReports>.
 
 The UUID of this report stored in standard hex string representation.
 
+=head2 created
+
+The ISO8601 date/time of when the report was inserted into the database.
+Will default to the current time.
+
 =head2 report
 
 The full JSON report.
@@ -89,6 +129,16 @@ The full JSON report.
 XXX: Describe the format a little and link to the main schema OpenAPI
 format on http://api.cpantesters.org
 
+=head1 METHODS
+
+=head2 new
+
+Create a new object. This is called automatically by the ResultSet
+object and should not be called directly.
+
+This is overridden to provide sane defaults for the C<id> and C<created>
+fields.
+
 =head1 SEE ALSO
 
 L<DBIx::Class::Row>, L<CPAN::Testers::Schema>
